package com.jkcredit.query.record.filter;

import com.jkcredit.query.record.service.TokenService;
import lombok.extern.slf4j.Slf4j;
import org.apache.catalina.connector.RequestFacade;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;

import javax.servlet.*;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;

/**
 * @author xusonglin
 * @version V1.0
 **/
@WebFilter(urlPatterns = "/*", filterName = "requestCheckFilter")
@Order(value = 1)
@Component
@Slf4j
public class RequestCheckFilter implements Filter {
    @Autowired
    TokenService tokenService;

    @Override
    public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
        log.info("request url:{}", ((RequestFacade) servletRequest).getRequestURI());
        if (((RequestFacade) servletRequest).getRequestURI().equals("/token")) {
            filterChain.doFilter(servletRequest, servletResponse);
        } else {
            HttpServletRequest httpServletRequest = (HttpServletRequest) servletRequest;
            String xToken = httpServletRequest.getHeader("X-Token");
            if (StringUtils.isBlank(xToken)) {
                // token不存在
                servletRequest.getRequestDispatcher("/tokenNotExist").forward(servletRequest, servletResponse);
            } else {
                // 验证token
                boolean validateResult = tokenService.validateToken(xToken);
                if (!validateResult) {
                    servletRequest.getRequestDispatcher("/tokenError").forward(servletRequest, servletResponse);
                } else {
                    filterChain.doFilter(servletRequest, servletResponse);
                }
            }
        }
    }
}
